@@ -25,8 +25,6 @@
 #include <Common.h>
 #include "cal-home-calendar-util.h"
 
-
-
 static time_t 
 cal_home_advance_date_by_time_period(struct tm* start,
 				     const CalTimePeriod& ctp)
@@ -187,6 +185,7 @@ cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
       GtkWidget* line = gtk_hbox_new(FALSE, 0);
 
       GtkWidget* time_label = gtk_label_new(time);
+      g_free(time);
       GtkWidget* cal_image = gtk_image_new_from_pixbuf(pixbuf);
 
       hildon_helper_set_logical_font(time_label,
@@ -197,6 +196,8 @@ cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
 				      "ActiveTextColor");
       GtkWidget* summary_label = gtk_label_new(NULL);
       gtk_label_set_markup(GTK_LABEL(summary_label), summary);
+      g_free(summary);
+      
       hildon_helper_set_logical_font(summary_label,
 				     "HomeSystemFont");
       hildon_helper_set_logical_color(summary_label,
@@ -213,8 +214,8 @@ cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
       gtk_box_pack_start(GTK_BOX(line), cal_image, FALSE, FALSE, 8);
       gtk_box_pack_start(GTK_BOX(desktop_plugin->event_list_container), line, TRUE, FALSE, 4);
       
-      g_free(time);
-      g_free(summary);
+
+
     }while(gtk_tree_model_iter_next(GTK_TREE_MODEL(desktop_plugin->event_list),
 				    &iter));
   }
@@ -243,6 +244,24 @@ cal_date_on_today(const time_t& t,
     time->tm_mday== desktop_plugin->date_today.tm_mday;
 }
 
+static void
+_format_time(gchar* buffer, struct tm* time, gboolean has_24_time_format)
+{
+  if(has_24_time_format)
+    strftime(buffer, 255,dgettext("hildon-libs","wdgt_va_24h_time"), time);
+  else
+  {
+    if(time->tm_hour>11)
+    {
+      strftime(buffer, 255,dgettext("hildon-libs","wdgt_va_12h_time_pm"), time);
+    }
+    else
+    {
+      strftime(buffer, 255,dgettext("hildon-libs","wdgt_va_12h_time_am"), time);
+    }
+  }
+}
+
 static void
 cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent_set,
 					   GtkListStore* list_store,
@@ -270,12 +289,18 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     gtk_list_store_append(list_store,
 			  &iter);
     string summary = (*event_iter)->getSummary();
-    if((*event_iter)->getType() == E_TODO)
+    if((*event_iter)->getType() == E_TODO &&
+       (*event_iter)->getStatus() == 1)
     {
-      if((*event_iter)->getStatus() == 1)
-      {
-	summary = "<s>"+ summary + "</s>";
-      }
+      gchar* escaped_markedup = g_markup_printf_escaped("<s>%s</s>", summary.c_str());
+      summary = string(escaped_markedup);
+      g_free(escaped_markedup);
+    }
+    else
+    {
+      gchar* escaped_markedup = g_markup_printf_escaped("%s", summary.c_str());
+      summary = string(escaped_markedup);
+      g_free(escaped_markedup);
     }
     time_t event_start_time = (*event_iter)->getDateStart();
     time_t event_end_time = (*event_iter)->getDateEnd();
@@ -287,16 +312,17 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       event_end_time += event_time_offset - system_time_offset;
       event_start_time += event_time_offset - system_time_offset;
     }
+    if(earliest_update_end_time>event_end_time)
+      earliest_update_end_time = end_time+60;
+    if(date_today_time < event_start_time &&
+       earliest_update_end_time > event_start_time)
+      earliest_update_end_time = event_start_time+60;
     char buf[255];
+
     if(cal_date_on_today(event_start_time, desktop_plugin) || 
        (event_start_time <= date_today_time && (event_end_time == -1 || event_end_time >= date_today_time)))
     {
       ++desktop_plugin->today_events;
-      if(earliest_update_end_time>event_end_time)
-	earliest_update_end_time = end_time+60;
-      if(date_today_time < event_start_time &&
-	 earliest_update_end_time > event_start_time)
-	earliest_update_end_time = event_start_time+60;
 
       if((*event_iter)->getAllDay() || (event_start_time <= date_today_time && 
 					end_time >= end_time_today))
@@ -307,19 +333,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       }
       else
       {
-	if(desktop_plugin->has_24_time_format)
-	  strftime(buf, 255,dgettext("hildon-libs","wdgt_va_24h_time"), time);
-	else
-	{
-	  if(time->tm_hour>11)
-	  {
-	    strftime(buf, 255,dgettext("hildon-libs","wdgt_va_12h_time_pm"), time);
-	  }
-	  else
-	  {
-	    strftime(buf, 255,dgettext("hildon-libs","wdgt_va_12h_time_am"), time);
-	  }
-	}
+	_format_time(buf, time, desktop_plugin->has_24_time_format);
 	gtk_list_store_set(list_store, &iter,
 			   0, buf,
 			   -1);
@@ -327,7 +341,10 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     }
     else
     {
-      strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), time);
+      if(desktop_plugin->show_week_day_name)
+	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_day_name_short"), time);
+      else
+	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), time);
       gtk_list_store_set(list_store, &iter,
 			 0, buf,
 			 -1);
