@@ -247,6 +247,7 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
 						  HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 
   GtkWidget* show_age = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  GtkWidget* show_week_day_name = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
 
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(show_age),
 				 desktop_plugin->show_age);
@@ -258,11 +259,17 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
   gtk_button_set_label(GTK_BUTTON(show_age),
 		       "Show persons age");
 
+  gtk_button_set_label(GTK_BUTTON(show_week_day_name),
+		       "Show weekday name");
+
   GtkWidget* update_if_visible = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
 
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(update_if_visible),
 				 desktop_plugin->update_if_visible);
 
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(show_week_day_name),
+				 desktop_plugin->show_week_day_name);
+
   gtk_button_set_label(GTK_BUTTON(update_if_visible),
 		       "Update when switch to the desktop");
 
@@ -327,6 +334,7 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
   gtk_box_pack_start(GTK_BOX(pan_content), show_age, FALSE, FALSE, 3);
   gtk_box_pack_start(GTK_BOX(pan_content), update_if_visible, FALSE, FALSE, 3);
   gtk_box_pack_start(GTK_BOX(pan_content), show_all_recurrence, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), show_week_day_name, FALSE, FALSE, 3);
   GtkWidget* visible_event_mode_box = gtk_hbox_new(TRUE, 0);
   gtk_box_pack_start(GTK_BOX(visible_event_mode_box), toggle_event_visible, TRUE, TRUE, 3);
   gtk_box_pack_start(GTK_BOX(visible_event_mode_box), toggle_task_visible, TRUE, TRUE, 3);
@@ -351,6 +359,7 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
     desktop_plugin->show_age = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_age));
     desktop_plugin->update_if_visible = hildon_check_button_get_active(HILDON_CHECK_BUTTON(update_if_visible));
     desktop_plugin->show_all_recurrences = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_all_recurrence));
+    desktop_plugin->show_week_day_name = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_week_day_name));
     if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_event_and_task_visible)))
     {
       desktop_plugin->visible_entry_mode = VISIBLE_ENTRY_EVENT_AND_TASK;
